/*
** Module : RemoteErrorData.java
** Public : provides remote access to ErrorManager data
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -----------------------------Description-----------------------------
** 001 NVS 20060303   @24884 Created initial version.
** 002 GES 20080624   @38915 Added support for an ignore flag. Changed
**                           some method names to match coding standards.
** 003 GES 20090924   @44009 Added headless mode flag.
** 004 CA  20130920          if ERROR attribute is set to false by ErrorManager.recordOrShowError,
**                           than do not clean the error message list.
** 005 CA  20131219          Renamed isError to isErrorFlag.
** 006 VIG 20140701          Removed setDontClean method and added forwardPending method. 
*/ 

package com.goldencode.p2j.util;

/**
 * Describes methods available for the use in the ErrorManager to access
 * the data residing on the server from both the server and client uniformly.
 *
 * @author NVS
 */
public interface RemoteErrorData
{
   /**
    * Queries the state of <code>silent</code> variable.
    *
    * @return   <code>true</code> if silent mode is enabled, otherwise
    *           <code>false</code>.
    */
   public boolean isSilent();    

   /**
    * Sets the <code>silent</code> variable.
    *
    * @param    value
    *           The new state of the variable.
    */
   public void setSilent(boolean value);    

   /**
    * Queries the state of <code>ignore</code> variable.
    *
    * @return   <code>true</code> if silent mode is enabled, otherwise
    *           <code>false</code>.
    */
   public boolean isIgnore();    

   /**
    * Sets the <code>ignore</code> variable.
    *
    * @param    value
    *           The new state of the variable.
    */
   public void setIgnore(boolean value);    

   /**
    * Queries the state of <code>error</code> variable.
    *
    * @return   <code>true</code> if error flag is turned on, otherwise
    *           <code>false</code>.
    */
   public boolean isErrorFlag();
   
   /**
    * Sets the <code>error</code> variable.
    *
    * @param    value
    *           The new state of the variable.
    */
   public void setError(boolean value);    

   /**
    * Queries the state of <code>pendingError</code> variable.
    *
    * @return   <code>true</code> if pending error flag is turned on, otherwise
    *           <code>false</code>.
    */
   public boolean isPending();    

   /**
    * Sets the <code>pendingError</code> variable.
    *
    * @param    value
    *           The new state of the variable.
    */
   public void setPending(boolean value);

   /**
    * Determines if headless mode should be supported. In headless mode, no
    * client-side output will occur.
    *
    * @return   <code>true</code> if the headless flag is turned on, otherwise
    *           <code>false</code>.
    */
   public boolean isHeadless();

   /**
    * Clears the list of error records.
    */
   public void clearList();    

   /**
    * Gets the size of the list of error records.
    *
    * @return   The size of the list.
    */
   public int getSize();    

   /**
    * Adds a record to the list of error records.
    *
    * @param    record
    *           The object to add to the list of error records.
    */
   public void addRecord(Object record);    

   /**
    * Gets a record from the list of error records.
    *
    * @param    index
    *           The record index.
    *
    * @return   The object associated with the given index in the list.
    */
   public Object getRecord(int index);
   
   /**
    * Makes pending error status current. 
    */
   public void forwardPending();
}
